@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2011 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2012 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -113,7 +113,8 @@ static int check_sys_dir(char *dir)
 		return EXIT_SUCCESS;
 
 	printf("Error - the folder '%s' was not found within the sys filesystem\n", dir);
-	printf("Please make sure that the batman-adv kernel module is loaded\n");
+	printf("Please make sure that the batman-adv kernel module is loaded and\n");
+	printf("that you have activated your mesh by adding interfaces to batman-adv\n");
 	return EXIT_FAILURE;
 }
 
