@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2011 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2012 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -163,10 +163,10 @@ int ping(char *mesh_iface, int argc, char **argv)
 	packet_len = sizeof(struct icmp_packet);
 
 	memcpy(&icmp_packet_out.dst, dst_mac, ETH_ALEN);
-	icmp_packet_out.packet_type = BAT_ICMP;
-	icmp_packet_out.version = COMPAT_VERSION;
+	icmp_packet_out.header.packet_type = BAT_ICMP;
+	icmp_packet_out.header.version = COMPAT_VERSION;
 	icmp_packet_out.msg_type = ECHO_REQUEST;
-	icmp_packet_out.ttl = 50;
+	icmp_packet_out.header.ttl = 50;
 	icmp_packet_out.seqno = 0;
 
 	if (rr) {
@@ -196,6 +196,7 @@ int ping(char *mesh_iface, int argc, char **argv)
 			goto sleep;
 		}
 
+read_packet:
 		start_timer();
 
 		FD_ZERO(&read_socket);
@@ -229,12 +230,16 @@ int ping(char *mesh_iface, int argc, char **argv)
 			goto sleep;
 		}
 
+		/* after receiving an unexpected seqno we keep waiting for our answer */
+		if (htons(seq_counter) != icmp_packet_in.seqno)
+			goto read_packet;
+
 		switch (icmp_packet_in.msg_type) {
 		case ECHO_REPLY:
 			time_delta = end_timer();
 			printf("%zd bytes from %s icmp_seq=%hu ttl=%d time=%.2f ms",
 					read_len, dst_string, ntohs(icmp_packet_in.seqno),
-					icmp_packet_in.ttl, time_delta);
+					icmp_packet_in.header.ttl, time_delta);
 
 			if (read_len == sizeof(struct icmp_packet_rr)) {
 				if (last_rr_cur == icmp_packet_in.rr_cur
@@ -283,7 +288,7 @@ int ping(char *mesh_iface, int argc, char **argv)
 			break;
 		case PARAMETER_PROBLEM:
 			printf("Error - the batman adv kernel module version (%d) differs from ours (%d)\n",
-					icmp_packet_in.version, COMPAT_VERSION);
+					icmp_packet_in.header.version, COMPAT_VERSION);
 			printf("Please make sure to use compatible versions!\n");
 			goto out;
 		default:
@@ -322,7 +327,10 @@ sleep:
 	printf("rtt min/avg/max/mdev = %.3f/%.3f/%.3f/%.3f ms\n",
 		min, avg, max, mdev);
 
-	ret = EXIT_SUCCESS;
+	if (packets_in)
+		ret = EXIT_SUCCESS;
+	else
+		ret = EXIT_NOSUCCESS;
 
 out:
 	bat_hosts_free();
